==> org.eclipse.lsp4j.debug-0.4.0.jar: org/eclipse/lsp4j/debug/CompletionsResponse.java <==
/**
 * Copyright (c) 2017 Kichwa Coders Ltd. and others.
 * All rights reserved. This program and the accompanying materials
 * are made available under the terms of the Eclipse Public License v1.0
 * which accompanies this distribution, and is available at
 * http://www.eclipse.org/legal/epl-v10.html
 */
package org.eclipse.lsp4j.debug;

import java.util.Arrays;
import org.eclipse.lsp4j.debug.CompletionItem;
import org.eclipse.lsp4j.jsonrpc.validation.NonNull;
import org.eclipse.xtext.xbase.lib.Pure;
import org.eclipse.xtext.xbase.lib.util.ToStringBuilder;

/**
 * Response to 'completions' request.
 */
@SuppressWarnings("all")
public class CompletionsResponse {
  /**
   * The possible completions for .
   */
  @NonNull
  private CompletionItem[] targets;
  
  /**
   * The possible completions for .
   */
  @Pure
  @NonNull
  public CompletionItem[] getTargets() {
    return this.targets;
  }
  
  /**
   * The possible completions for .
   */
  public void setTargets(@NonNull final CompletionItem[] targets) {
    this.targets = targets;
  }
  
  @Override
  @Pure
  public String toString() {
    ToStringBuilder b = new ToStringBuilder(this);
    b.add("targets", this.targets);
    return b.toString();
  }
  
  @Override
  @Pure
  public boolean equals(final Object obj) {
    if (this == obj)
      return true;
    if (obj == null)
      return false;
    if (getClass() != obj.getClass())
      return false;
    CompletionsResponse other = (CompletionsResponse) obj;
    if (this.targets == null) {
      if (other.targets != null)
        return false;
    } else if (!Arrays.deepEquals(this.targets, other.targets))
      return false;
    return true;
  }
  
  @Override
  @Pure
  public int hashCode() {
    final int prime = 31;
    int result = 1;
    result = prime * result + ((this.targets== null) ? 0 : Arrays.deepHashCode(this.targets));
    return result;
  }
}

==> org.eclipse.lsp4j.debug-0.7.2.jar: org/eclipse/lsp4j/debug/CompletionsResponse.java <==
/**
 * Copyright (c) 2017, 2018 Kichwa Coders Ltd. and others.
 * 
 * This program and the accompanying materials are made available under the
 * terms of the Eclipse Public License v. 2.0 which is available at
 * http://www.eclipse.org/legal/epl-2.0,
 * or the Eclipse Distribution License v. 1.0 which is available at
 * http://www.eclipse.org/org/documents/edl-v10.php.
 * 
 * SPDX-License-Identifier: EPL-2.0 OR BSD-3-Clause
 */
package org.eclipse.lsp4j.debug;

import java.util.Arrays;
import org.eclipse.lsp4j.debug.CompletionItem;
import org.eclipse.lsp4j.jsonrpc.validation.NonNull;
import org.eclipse.xtext.xbase.lib.Pure;
import org.eclipse.xtext.xbase.lib.util.ToStringBuilder;

/**
 * Response to 'completions' request.
 */
@SuppressWarnings("all")
public class CompletionsResponse {
  /**
   * The possible completions for .
   */
  @NonNull
  private CompletionItem[] targets;
  
  /**
   * The possible completions for .
   */
  @Pure
  @NonNull
  public CompletionItem[] getTargets() {
    return this.targets;
  }
  
  /**
   * The possible completions for .
   */
  public void setTargets(@NonNull final CompletionItem[] targets) {
    if (targets == null) {
      throw new IllegalArgumentException("Property must not be null: targets");
    }
    this.targets = targets;
  }
  
  @Override
  @Pure
  public String toString() {
    ToStringBuilder b = new ToStringBuilder(this);
    b.add("targets", this.targets);
    return b.toString();
  }
  
  @Override
  @Pure
  public boolean equals(final Object obj) {
    if (this == obj)
      return true;
    if (obj == null)
      return false;
    if (getClass() != obj.getClass())
      return false;
    CompletionsResponse other = (CompletionsResponse) obj;
    if (this.targets == null) {
      if (other.targets != null)
        return false;
    } else if (!Arrays.deepEquals(this.targets, other.targets))
      return false;
    return true;
  }
  
  @Override
  @Pure
  public int hashCode() {
    return 31 * 1 + ((this.targets== null) ? 0 : Arrays.deepHashCode(this.targets));
  }
}
